#!/usr/bin/perl

my $x = 1 + (10 / 12) + 15;
my $y = 3 + (10 / 12) + 17;
